@@ -3,12 +3,13 @@ package Graph::Undirected;
 use Graph;
 use base 'Graph';
 use strict;
+use warnings;
 
 =pod
 
 =head1 NAME
 
-Graph::Undirected - directed graphs
+Graph::Undirected - undirected graphs
 
 =head1 SYNOPSIS
 
